lang_interpreter::interpreter::data

Struct DataObject

pub struct DataObject { /* private fields */ }

Implementations

Source

impl DataObject

pub fn get_type_constraint_for( variable_name: Option<&str>, ) -> &DataTypeConstraint

pub fn new() -> Self

Creates a new data object of type NULL

pub fn new_text(str: impl Into<Rc<str>>) -> Self

pub fn new_final_text(str: impl Into<Rc<str>>) -> Self

pub fn with_update( func: impl FnOnce(&mut Self) -> Result<&mut DataObject, DataTypeConstraintError>, ) -> Result<DataObject, DataTypeConstraintError>

This method allows the use of the rust “?” operator for data object creation

pub fn with_update_final( func: impl FnOnce(&mut Self) -> Result<&mut DataObject, DataTypeConstraintError>, ) -> Result<DataObject, DataTypeConstraintError>

This method allows the use of the rust “?” operator for data object creation and sets final data to true

pub fn update( &mut self, func: impl FnOnce(&mut Self) -> Result<&mut DataObject, DataTypeConstraintError>, ) -> Result<(), DataTypeConstraintError>

This method allows the use of the rust “?” operator for data object updates

pub fn update_final( &mut self, func: impl FnOnce(&mut Self) -> Result<&mut DataObject, DataTypeConstraintError>, ) -> Result<(), DataTypeConstraintError>

This method allows the use of the rust “?” operator for data object updates and sets final data to true

pub fn set_data( &mut self, data_object: &DataObject, ) -> Result<&mut Self, DataTypeConstraintError>

This method ignores the final and static state of the data object
This method will not modify variableName
This method will also not modify finalData nor staticData (Except: copyStaticAndFinalModifiers flag is set)

pub fn set_text( &mut self, value: impl Into<Rc<str>>, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn text_value(&self) -> Option<&str>

pub fn set_byte_buffer( &mut self, value: Box<[u8]>, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn byte_buffer_value(&self) -> Option<Rc<RefCell<Box<[u8]>>>>

pub fn set_array( &mut self, value: Box<[DataObjectRef]>, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn array_value(&self) -> Option<Rc<RefCell<Box<[DataObjectRef]>>>>

pub fn set_list( &mut self, value: VecDeque<DataObjectRef>, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn list_value(&self) -> Option<Rc<RefCell<VecDeque<DataObjectRef>>>>

pub fn set_var_pointer( &mut self, value: DataObjectRef, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn var_pointer_value(&self) -> Option<DataObjectRef>

pub fn set_function_pointer( &mut self, value: FunctionPointerObjectRef, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn function_pointer_value(&self) -> Option<FunctionPointerObjectRef>

pub fn set_struct( &mut self, value: Rc<StructObject>, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn struct_value(&self) -> Option<Rc<StructObject>>

pub fn set_object( &mut self, value: LangObjectRef, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn object_value(&self) -> Option<LangObjectRef>

pub fn set_null(&mut self) -> Result<&mut Self, DataTypeConstraintError>

pub fn set_void(&mut self) -> Result<&mut Self, DataTypeConstraintError>

pub fn set_number( &mut self, value: Number, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn set_int( &mut self, value: i32, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn int_value(&self) -> Option<i32>

pub fn set_bool( &mut self, value: bool, ) -> Result<&mut Self, DataTypeConstraintError>

Sets data to INT = 1 if boolean value is true else INT = 0

pub fn set_long( &mut self, value: i64, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn long_value(&self) -> Option<i64>

pub fn set_float( &mut self, value: f32, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn float_value(&self) -> Option<f32>

pub fn set_double( &mut self, value: f64, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn double_value(&self) -> Option<f64>

pub fn set_char( &mut self, value: char, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn char_value(&self) -> Option<char>

pub fn set_error( &mut self, value: Rc<ErrorObject>, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn error_value(&self) -> Option<Rc<ErrorObject>>

pub fn set_type( &mut self, value: DataType, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn type_value(&self) -> Option<DataType>

pub fn set_variable_name( &mut self, variable_name: Option<&str>, ) -> Result<&mut Self, DataTypeConstraintError>

pub fn variable_name(&self) -> Option<&str>

pub fn set_final_data(&mut self, final_data: bool) -> &mut Self

pub fn is_final_data(&self) -> bool

pub fn set_static_data(&mut self, final_data: bool) -> &mut Self

pub fn is_static_data(&self) -> bool

pub fn is_copy_static_and_final_modifiers(&self) -> bool

pub fn is_lang_var(&self) -> bool

pub fn data_type(&self) -> DataType

pub fn type_constraint(&self) -> &DataTypeConstraint

pub fn check_type( &self, data_type: DataType, ) -> Result<(), DataTypeConstraintError>

pub fn member_visibility(&self) -> Option<Visibility>

pub fn member_of_class(&self) -> i64

pub fn is_accessible(&self, accessing_class: Option<&LangObjectRef>) -> bool